@@ -50,7 +50,8 @@ GstDialogSignal signals[] = {
 	{ "connection_configure",    "clicked",         G_CALLBACK (on_connection_configure_clicked) },
 	{ "connection_activate",     "clicked",         G_CALLBACK (on_connection_activate_button_clicked) },
 	{ "connection_deactivate",   "clicked",         G_CALLBACK (on_connection_deactivate_button_clicked) },
-	{ "connection_def_gw_omenu", "changed",         G_CALLBACK (gst_dialog_modify_cb) },
+	{ "connection_def_gw_menu",  "changed",         G_CALLBACK (on_connection_default_gw_activate) },
+	{ "connection_def_gw_menu",  "changed",         G_CALLBACK (gst_dialog_modify_cb) },
 	{ "domain",                  "changed",         G_CALLBACK (gst_dialog_modify_cb) },
 /*	{ "ip",                      "changed",         G_CALLBACK (gst_dialog_modify_cb) },*/
 	{ "ip",                      "changed",         G_CALLBACK (on_hosts_ip_changed) },
@@ -75,6 +76,7 @@ GstDialogSignal signals[] = {
 	/* Network druid callbacks */
 	{ "network_connection_window",       "delete_event",  G_CALLBACK (on_network_druid_hide) },
 	{ "network_connection_druid",        "cancel", G_CALLBACK (on_network_druid_hide) },
+	{ "network_connection_druid",        "help",   G_CALLBACK (on_network_druid_help) },
 	{ "network_connection_page1",        "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_page2",        "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_wireless_page",  "next",   G_CALLBACK (on_network_druid_page_next) },
@@ -82,16 +84,16 @@ GstDialogSignal signals[] = {
 	{ "network_connection_plip_page1",   "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_ppp_page1",    "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_ppp_page2",    "next",   G_CALLBACK (on_network_druid_page_next) },
-	{ "network_connection_page_name",         "next",   G_CALLBACK (on_network_druid_page_next) },
+	{ "network_connection_page_activate", "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_page2",        "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_wireless_page",  "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_other_page1",  "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_plip_page1",  "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_ppp_page1",    "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_ppp_page2",    "back",   G_CALLBACK (on_network_druid_page_back) },
-	{ "network_connection_page_name",    "back",   G_CALLBACK (on_network_druid_page_back) },
+	{ "network_connection_page_activate", "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_page_finish",  "back",   G_CALLBACK (on_network_druid_page_back) },
-	{ "network_connection_wireless_device_entry", "changed", G_CALLBACK (on_network_druid_entry_changed) },
+	{ "network_connection_wireless_device", "changed", G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_essid", "changed", G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_other_config_type", "changed", G_CALLBACK (on_network_druid_config_type_changed) },
 	{ "network_connection_other_ip_address", "changed", G_CALLBACK (on_network_druid_entry_changed) },
@@ -103,11 +105,12 @@ GstDialogSignal signals[] = {
 	{ "network_connection_ppp_login",    "changed",   G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_ppp_passwd1",  "changed",   G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_ppp_passwd2",  "changed",   G_CALLBACK (on_network_druid_entry_changed) },
-	{ "network_connection_name",         "changed",   G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_page_finish",  "finish",    G_CALLBACK (on_network_druid_finish) },
 	{ "network_connection_other_ip_address", "focus_out_event", G_CALLBACK (on_network_druid_ip_address_focus_out) },
 
 	/* Network profiles callbacks */
+	{ "network_profiles_help", "clicked", G_CALLBACK (on_network_profile_help_clicked) },
+	{ "network_profiles_menu", "changed", G_CALLBACK (on_network_profile_option_selected) },
 	{ "network_profiles_button", "clicked", G_CALLBACK (on_network_profiles_button_clicked) },
 	{ "network_profile_new", "clicked", G_CALLBACK (on_network_profile_new_clicked) },
 	{ "network_profile_delete", "clicked", G_CALLBACK (on_network_profile_delete_clicked) },
@@ -116,16 +119,17 @@ GstDialogSignal signals[] = {
 	{ "connection_config_dialog", "delete_event", G_CALLBACK (on_connection_delete_event) },
 	{ "connection_cancel", "clicked", G_CALLBACK (on_connection_cancel_clicked) },
 	{ "connection_ok", "clicked", G_CALLBACK (on_connection_ok_clicked) },
+	{ "connection_help", "clicked", G_CALLBACK (on_connection_help_clicked) },
 	{ "ppp_autodetect_modem", "clicked", G_CALLBACK (on_ppp_autodetect_modem_clicked) },
 	{ "ppp_volume", "format_value", G_CALLBACK (on_volume_format_value) },
 	{ "ip_address", "focus_out_event", G_CALLBACK (on_ip_address_focus_out) },
 	{ "ip_netmask", "focus_out_event", G_CALLBACK (on_ip_address_focus_out) },
 	{ "ppp_update_dns", "toggled", G_CALLBACK (on_ppp_update_dns_toggled) },
-	{ "connection_name", "changed", G_CALLBACK (on_connection_modified) },
 	{ "status_autoboot", "toggled", G_CALLBACK (on_connection_modified) },
 	{ "status_user", "toggled", G_CALLBACK (on_connection_modified) },
 	{ "wlan_essid", "changed", G_CALLBACK (on_connection_modified) },
-	{ "connection_config", "clicked", G_CALLBACK (on_connection_modified) },
+	{ "connection_config", "changed", G_CALLBACK (on_connection_ip_config_changed) },
+	{ "connection_config", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ip_address", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ip_netmask", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ip_gateway", "changed", G_CALLBACK (on_connection_modified) },
@@ -133,8 +137,7 @@ GstDialogSignal signals[] = {
 	{ "ptp_address", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ptp_remote_address", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ptp_remote_is_gateway", "toggled", G_CALLBACK (on_connection_modified) },
-	{ "ppp_serial_port", "changed", G_CALLBACK (on_connection_modified) },
-	{ "ppp_dial_command", "clicked", G_CALLBACK (on_connection_modified) },
+	{ "ppp_dial_command", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ppp_volume", "value_changed", G_CALLBACK (on_connection_modified) },
 	{ "ppp_persist", "toggled", G_CALLBACK (on_connection_modified) },
 	{ "ppp_phone_number", "changed", G_CALLBACK (on_connection_modified) },
@@ -150,15 +153,14 @@ GstDialogSignal signals[] = {
 };
 
 GstDialogSignal signals_after[] = {
-	{ "network_connection_page1", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_page2", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page2",         "prepare", G_CALLBACK (on_network_druid_page_prepare) },
 	{ "network_connection_wireless_page", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_other_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_plip_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_ppp_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_ppp_page2", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_page_name", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_page_finish", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_other_page1",   "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_plip_page1",    "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_ppp_page1",     "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_ppp_page2",     "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page_activate", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page_finish",   "prepare", G_CALLBACK (on_network_druid_page_prepare) },
 	{ NULL }
 };
 
@@ -170,8 +172,19 @@ static GstReportHookEntry report_hooks[] = {
 static void
 connect_signals (GstDialog *main_dialog, GstDialogSignal *sigs, GstDialogSignal *sigs_after)
 {
+	GtkWidget *widget;
+	
 	gst_dialog_connect_signals (main_dialog, sigs);
 	gst_dialog_connect_signals_after (main_dialog, sigs_after);
+
+	/* FIXME: do this here until the GtkComboBox child is accessible through glade */
+	widget = gst_dialog_get_widget (main_dialog, "network_connection_wireless_device");
+	g_signal_connect (GTK_BIN (GTK_COMBO_BOX (widget))->child,
+			  "changed", G_CALLBACK (on_network_druid_entry_changed), NULL);
+
+	widget = gst_dialog_get_widget (main_dialog, "ppp_serial_port");
+	g_signal_connect (GTK_BIN (GTK_COMBO_BOX (widget))->child,
+			  "changed", G_CALLBACK (on_connection_modified), NULL);
 }
 
 int
@@ -236,6 +249,7 @@ main (int argc, char *argv[])
 
 		connect_signals (tool->main_dialog, signals, signals_after);
 		init_editable_filters (tool->main_dialog);
+		on_network_admin_show (NULL, tool);
 
 		gst_tool_main_with_hidden_dialog (tool, TRUE);
 
@@ -256,7 +270,6 @@ main (int argc, char *argv[])
 		gst_tool_set_xml_funcs (tool, transfer_xml_to_gui, transfer_gui_to_xml, NULL);
 
 		init_editable_filters (tool->main_dialog);
-
 		on_network_admin_show (NULL, tool);
 
 		gst_tool_main (tool, TRUE);
@@ -265,7 +278,8 @@ main (int argc, char *argv[])
 			g_signal_emit_by_name (G_OBJECT (gst_dialog_get_widget (tool->main_dialog, "connection_add")),
 					       "clicked",
 					       NULL);
-
+		on_network_notebook_switch_page (gst_dialog_get_widget (tool->main_dialog, "network_admin_notebook"),
+						 NULL, 0, NULL);
 		gtk_main ();
 	}
 		
